Francois Gouget : testbot: Rename the staging files for the mailing list patches.

Alexandre Julliard julliard at winehq.org
Thu Jan 23 15:46:59 CST 2020


Module: tools
Branch: master
Commit: 17fe807807c3106fa226447c61de4c77fe7570fe
URL:    https://source.winehq.org/git/tools.git/?a=commit;h=17fe807807c3106fa226447c61de4c77fe7570fe

Author: Francois Gouget <fgouget at codeweavers.com>
Date:   Thu Jan 23 10:41:02 2020 +0100

testbot: Rename the staging files for the mailing list patches.

There is no need to use the mailing list name for those files.
Also make it clear that these files contain the email, not just
the patch.

Signed-off-by: Francois Gouget <fgouget at codeweavers.com>
Signed-off-by: Alexandre Julliard <julliard at winehq.org>

---

 testbot/bin/Engine.pl              | 4 ++--
 testbot/bin/Janitor.pl             | 2 +-
 testbot/bin/WinePatchesMLSubmit.pl | 2 +-
 3 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/testbot/bin/Janitor.pl b/testbot/bin/Janitor.pl
index 115b7d5..bf3989a 100755
--- a/testbot/bin/Janitor.pl
+++ b/testbot/bin/Janitor.pl
@@ -276,7 +276,7 @@ if (opendir(my $dh, "$DataDir/staging"))
       # These files always expire after one day
       $TTL = 1 - $Age;
     }
-    elsif ($Entry !~ /^[0-9a-f]{32}_(?:patch\.diff|patchset\.diff|wine-patches|winetest(?:64)?-latest\.exe)$/)
+    elsif ($Entry !~ /^[0-9a-f]{32}_(?:patch\.diff|patchset\.diff|email|winetest(?:64)?-latest\.exe)$/)
     {
       my $Deletion = defined $TTL ? " (deletion in $TTL days)" : "";
       Error "Found a suspicious file$Deletion: staging/$Entry\n";
diff --git a/testbot/bin/WinePatchesMLSubmit.pl b/testbot/bin/WinePatchesMLSubmit.pl
index bddd42c..4797e98 100755
--- a/testbot/bin/WinePatchesMLSubmit.pl
+++ b/testbot/bin/WinePatchesMLSubmit.pl
@@ -45,7 +45,7 @@ use WineTestBot::Engine::Notify;
 use WineTestBot::Log;
 
 # Store the message in the staging dir
-my ($fh, $FileName) = OpenNewFile("$DataDir/staging", "_wine-patches");
+my ($fh, $FileName) = OpenNewFile("$DataDir/staging", "_email");
 if (!$fh)
 {
   LogMsg "Could not create a staging file: $!\n";




More information about the wine-cvs mailing list
diff --git a/testbot/bin/Engine.pl b/testbot/bin/Engine.pl
index ca35233..a8fc2f0 100755
--- a/testbot/bin/Engine.pl
+++ b/testbot/bin/Engine.pl
@@ -420,13 +420,13 @@ sub HandleWinePatchMLSubmission()
   foreach my $Entry (@Entries)
   {
     # Validate file name
-    next if ($Entry !~ m/^([0-9a-fA-F]{32}_wine-patches)$/);
+    next if ($Entry !~ m/^([0-9a-fA-F]{32}_email)$/);
     my $FullMessageFileName = "$DataDir/staging/$1";
 
     # Create a work directory
     my $WorkDir = CreateNewDir("$DataDir/staging", "_work");
 
     # Process the patch
     my $Parser = new MIME::Parser;
     $Parser->output_dir($WorkDir);
     my $Entity = $Parser->parse_open($FullMessageFileName);
@@ -420,13 +420,13 @@ sub HandleWinePatchMLSubmission()
     my $WorkDir = CreateNewDir("$DataDir/staging", "_work");
 
-    # Process the patch
+    # Process the email
     my $Parser = new MIME::Parser;
     $Parser->output_dir($WorkDir);